@@ -1,12 +1,14 @@
 class Char:
     type = "char"
 
-    def __init__(self, length=8, default=None, null=False, primary=False, comment=None):
+    def __init__(self, length=8, default=None, null=False,
+                 primary=False, comment=None, unique=False):
         self.length = length
         self.default = default
         self.null = null
         self.primary = primary
         self.comment = comment
+        self.unique = unique
         self.auto = False
         self._value = None
 
