@@ -1,3 +1,4 @@
+import datetime
 from datetime import date
 
 
@@ -27,8 +28,8 @@ class Date:
                 raise ValueError("日期不正确!")
             year, month, day = map(int, dates)
             self._value = date(year, month, day)
-        elif isinstance(value, date):
-            self._value = date
+        elif isinstance(value, datetime.date):
+            self._value = value
         elif value:
             raise TypeError("日期类型不正确!")
 
