@@ -5,17 +5,18 @@ import time
 class DateTime:
     type = "datetime"
 
-    def __init__(self, length=20, default=None, null=False, auto=True, primary=False, comment=None):
-        self.length = length
+    def __init__(self, default=None, null=False, auto=True, primary=False, comment=None, unique=False):
+        self.length = None
         self.default = default
         self.null = null
         self.primary = primary
         self.comment = comment
         self.auto = auto
+        self.unique = unique
         self._value = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
 
     def __len__(self):
-        return self.length
+        return 19
 
     def __set__(self, instance, value):
         if not value and self.auto:
