@@ -1,13 +1,14 @@
 class Float:
     type = "float"
 
-    def __init__(self, length=11, default=None, null=False, primary=False, comment=None):
+    def __init__(self, length=11, default=None, null=False, primary=False, comment=None, unique=False):
         self.length = length
         self.default = default
         self.null = null
         self.primary = primary
         self.auto = False
         self.comment = comment
+        self.unique = unique
 
     def __len__(self):
         return self.length
