@@ -2,13 +2,14 @@ class Integer:
     _value = 0
     type = "integer"
 
-    def __init__(self, length=11, default=None, null=False, auto=False, primary=False, comment=None):
+    def __init__(self, length=11, default=None, null=False, auto=False, primary=False, comment=None, unique=False):
         self.length = length
         self.default = default
         self.null = null
         self.primary = primary
         self.auto = auto
         self.comment = comment
+        self.unique = unique
 
     def __len__(self):
         return self.length
