@@ -1,5 +1,8 @@
+import datetime
+
 from pydb3.config.property import FieldProperty
 from pydb3.sql.generator.table import TableGenerator
+import openpyxl
 
 other = ("__module__", "__main__", "__init__", "__doc__", "db", 'table')
 
@@ -76,6 +79,17 @@ class Model:
             items.append(obj)
         return items
 
+    @classmethod
+    def export_excel(cls, excel_path, models):
+        wb = openpyxl.Workbook()
+        sheet = wb.create_sheet(cls.__name__.lower())
+        titles = [key for key in cls.__dict__.keys() if key not in other]
+        sheet.append(titles)
+        for m in models:
+            item = [getattr(m, t) for t in titles]
+            sheet.append(item)
+        wb.save(excel_path)
+
     def __repr__(self):
         fields = list()
         for key, value in self.__class__.__dict__.items():
